summaryrefslogtreecommitdiffstats
path: root/src/conn-avoid-ref.h
diff options
context:
space:
mode:
authormjwybrow <mjwybrow@users.sourceforge.net>2006-02-14 00:36:28 +0000
committermjwybrow <mjwybrow@users.sourceforge.net>2006-02-14 00:36:28 +0000
commitfa668afcbd7dc12ef748e0d0b4fd62fb9441c13e (patch)
treedd81610ccafce158141f5e63505aeac2c4fe3b6e /src/conn-avoid-ref.h
parentextending the font selector preview string (patch #1240559 by cmarqu) (diff)
downloadinkscape-fa668afcbd7dc12ef748e0d0b4fd62fb9441c13e.tar.gz
inkscape-fa668afcbd7dc12ef748e0d0b4fd62fb9441c13e.zip
* src/graphlayout/graphlayout.cpp, src/conn-avoid-ref.cpp,
src/conn-avoid-ref.h, src/libavoid/connector.cpp, src/libavoid/connector.h: Change the behaviour and naming of some connector querying code after feedback from Tim Dwyer in implementing graph drawing functionality. (bzr r136)
Diffstat (limited to 'src/conn-avoid-ref.h')
-rw-r--r--src/conn-avoid-ref.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/conn-avoid-ref.h b/src/conn-avoid-ref.h
index 28d5de28a..a30dc4b93 100644
--- a/src/conn-avoid-ref.h
+++ b/src/conn-avoid-ref.h
@@ -31,11 +31,12 @@ public:
void setAvoid(char const *value);
void handleSettingChange(void);
// Returns a list of SPItems of all connectors attached to this
// object. Pass one of the following for 'type':
// Avoid::ConnRef::runningTo
// Avoid::ConnRef::runningFrom
// Avoid::ConnRef::runningToAndFrom
+ GSList *getAttachedShapes(const unsigned int type);
GSList *getAttachedConnectors(const unsigned int type);
private:
@@ -31,11 +31,12 @@ public:
void setAvoid(char const *value);
void handleSettingChange(void);
- // Returns a list of SPItems of all connectors attached to this
- // object. Pass one of the following for 'type':
+ // Returns a list of SPItems of all connectors/shapes attached to
+ // this object. Pass one of the following for 'type':
// Avoid::ConnRef::runningTo
// Avoid::ConnRef::runningFrom